import { Ref } from 'vue';
import { BasicPageParams, BasicFetchResult } from '/@/api/model/baseModel';
import { ActionItem } from '/@/components/Table';
import { CustModalParams } from './systemModel';
//物料信息实体
export type MaterialInfoParams = {
  ITEM_CODE?: string;
};
export type MaterialInfoPageParams = BasicPageParams & MaterialInfoParams;
export interface MaterialInfoListItem {
  ID: string;
  CREATE_TIME: string;
  CREATE_USER: string;
  UPDATE_TIME: string;
  UPDATE_USER: string;
  ITEM_CODE: string;
  ITEM_NAME: string;
  ITEM_TYPE: string;
  ITEM_VER: string;
  SPEC: string;
  SPEC_WH: string;
  FACTORY: string;
  ITEM_FAMILY: string;
  ITEM_MODEL: string;
  ITEM_LINE: string;
  COLOR: string;
  UNIT: string;
  LIFT_STATUS: string;
  CONTROL_TYPE: string;
  USAGE_FLAG: string;
  RELEASE_TIME: string;
  EFFECTIVE_TIME: string;
  REMARK: string;
  FNUMBER_ID: string;
  DLVY_TYPE: number;
  FITEMID: number;
  PURCHASER: string;
  LEAD_TIME: number;
}
//供应商信息实体
export type SupplierInfoParams = {
  SUPP_CODE?: string;
  SUPP_NAME?: string;
};
export type SupplierInfoPageParams = BasicPageParams & SupplierInfoParams;
export interface SupplierInfoListItem {
  ID: string;
  CREATE_TIME: string;
  CREATE_USER: string;
  UPDATE_TIME: string;
  UPDATE_USER: string;
  SUPP_CODE: string;
  SUPP_NAME: string;
  SUPP_TYPE: string;
  SUPP_LEVEL: string;
  SUPP_REGION: string;
  SUPP_ADDRESS: string;
  SUPP_EMAIL: string;
  REMARK: string;
  SUPP_IC: string;
}
// 包装信息 - 包装规则
export type PackageRuleParams = {
  SN?: string;
  PARENT_SN?: string;
  ITEM_CODE?: string;
  TRANS_NO?: string;
  WH_CODE?: string;
  REGION_CODE?: string;
};
export type PackageRulePageParams = BasicPageParams & PackageRuleParams;
export interface PackageRuleListItem {
  ID: string;
  CREATE_TIME: string;
  CREATE_USER: string;
  UPDATE_TIME: string;
  UPDATE_USER: string;
  GHOST_ROW: boolean;
  AUTH_ORG: string;
  AUTH_PROD: string;
  AUTH_WH: string;
  SN: string;
  SN_TYPE: number;
  PARENT_SN: string;
  PKG_TYPE: number;
  ITEM_CODE: string;
  QTY: number;
  UNIT: string;
  TRANS_CODE: string;
  TRANS_NO: string;
  TRANS_LINE: number;
  SUPP_CODE: string;
  SUPP_LOTNO: string;
  LOTNO: string;
  WH_CODE: string;
  REGION_CODE: string;
  SHELF_CODE: string;
  LOCATION_CODE: string;
  ERP_WH: string;
  PRINT_TIMES: number;
  PRINT_DATE: string;
  PRINT_USER: string;
  REMARK: string;
}

export interface NavItem {
  title: string;
  icon: string;
  color: string;
  url: string;
  action: string;
  isStep: boolean;
}

export type MaterialInfoPageListGetResultModel = BasicFetchResult<MaterialInfoListItem>;
export type SupplierInfoPageListGetResultModel = BasicFetchResult<SupplierInfoListItem>;
export type PackageRulePageListGetResultModel = BasicFetchResult<PackageRuleListItem>;

/**
 * @description: 自定义方法接口
 * @return {*}
 */
export interface EntityCustFunctionType {
  CreateAction: (fnName: string) => {};
  ActionItem: (params: Recordable<any>, data, ...args) => ActionItem[];
  EditOperation: (data: Ref<any[]>, d, u, item: string | undefined) => void;
  OpenSelectItem: (openItemModal: Fn, ...args) => void;
  GetSelectSuccess: (d, u, ...args) => {};
  GetHomeUrl: (params: {} | undefined) => string;
  GetBaseColumns: (type: string | undefined) => [] | {};
  GetSearchForm: (type: string | undefined) => [] | {};
  GetCrudForm: (type: string | undefined) => [] | {};
  GetBaseForm: () => [] | {};
  GetBaseCards: (type: string | undefined) => [];
  KeyFieldValues: (val: string, id: string) => {};
  GetTitle: (type: string | undefined) => {};
  GetCrudColSlots: () => [];
  nodeChange: ({}) => void;
  CreateIcon: (params: Recordable<any>) => string;
  SelectNode: (selectedNodes: Ref<any[]>) => {};
  GetNavItems: (type: string) => NavItem[];
  navChangeItem: (action: any, ...args) => void;
  GetUseModals: () => {};
  GetUseDrawers: () => [];
  GetUseTables: (data: Ref<Recordable[]>, ...args) => {};
  GetUseForm: (...args) => {};
  SubmitFunc: (values: Recordable<any>, type: string, emit) => void;
  FormSearch: (d) => string | {};
  GetSlots: (type: string | undefined) => {};
  GenerateHtml: (type: string | null) => HTMLElement | null;
  CustFunc: (param: CustModalParams) => void | any;
  SubmitAll: (data: Ref<any[]>, keyFieldValues: Ref<{}>, ...args) => void | any;
  CustInitData: (data: Ref<any[]>, keyFieldValues: Ref<{}>, type: string) => void | any;
  GetCustData: () => {};
}
